<?php
/*
Plugin Name: Nice Login Widget
Plugin URI: http://www.superplug.in
Description: Add, build and manage login-register widget
Version: 1.2
Author: SuperPlugin Team
Author URI: http://superplug.in/team/
*/

class Pw_Login_Widget extends WP_Widget
{
	
	
	/**
	 * The class constructor
	 *
	 * This setup the class and generate
	 *
	 *
	 */
	public function __construct() {
	
		$widget_options = array();
		$control_options = array();
		parent::__construct(
				'pw_login_widget',
				'Nice Login/Register Widget',
				array('description' => 'Add, build and manage login-register widget')
		);
	
	}

	/**
	 * Back-end widget form.
	 *
	 * @see WP_Widget::form()
	 *
	 * @param array $instance Previously saved values from database.
	 *
	 */
	public function form( $instance ) {
	
		if ( !empty( $instance[ 'include_remember_me' ] ) ) {
			$checked = "checked";
		}
		if ( isset( $instance[ 'logged_in_text' ] ) ) {
			$logged_in_text = $instance[ 'logged_in_text' ];
		}
		
		if ( !empty( $instance[ 'default_form' ] )){
			if ($instance[ 'default_form' ]=='login_form'){
				$login_form = "selected";
			}else if ($instance[ 'default_form' ]=='register_form'){
				$register_form = "selected";
			}
		}
		
		if ( isset( $instance[ 'float' ] ) && $instance[ 'float' ]=='horizontal'){
			$horizontal = "selected";
		}else{
			$vertical = "selected";
		}
		
		if (isset($instance['css_class'])){
			$css_class = $instance['css_class'];
		}else{
			$css_class = "";
		}
		add_thickbox();
		?>
			<h3>Widget Options</h3>
			
			<div class="sp-widget-back-end-div">
			<p>
			<label for="<?php echo $this->get_field_id("css_class"); ?>"><strong>CSS class name: </strong></label>
			<input type="text" id="<?php echo $this->get_field_id("css_class"); ?>" name="<?php echo $this->get_field_name("css_class"); ?>" value="<?php echo $css_class; ?>" >
			</p>
			<p><a href="#" class="sp_switch_logged_out"><strong>Logged Out Options</strong></a></p>
			<div style="display: none;" >
			<p>
			<label for="<?php echo $this->get_field_id('default_form'); ?>" ><strong>Default Form: </strong></label>
			<select id="<?php echo $this->get_field_id("default_form"); ?>" name="<?php echo $this->get_field_name("default_form"); ?>" >
			<option value="login_form" <?php echo $login_form; ?>>Login Form</option>
			<option value="register_form" <?php echo $register_form; ?>>Register Form</option>
			</select>
			</p>
			<p>
			<label for="<?php echo $this->get_field_id('float'); ?>" ><strong>Float: </strong></label>
			<select id="<?php echo $this->get_field_id("float"); ?>" name="<?php echo $this->get_field_name("float"); ?>" >
			<option value="horizontal" <?php echo $horizontal; ?>>Horizontal</option>
			<option value="vertical" <?php echo $vertical; ?>>Vertical</option>
			</select>
			</p>
			<p><label for="<?php echo $this->get_field_id( 'include_remember_me' ); ?>" ><strong>Include "Remember-Me"</strong>
			<input type="checkbox" id="<?php echo $this->get_field_id( 'include_remember_me' ); ?>" title="Include Remember-me"  name="<?php echo $this->get_field_name( 'include_remember_me' ); ?>" <?php echo $checked; ?> /></label>
			</p>
			
			<div style="display:none;">
			<p>
			<label><input type="radio" name="<?php echo $this->get_field_name("remember_me_def"); ?>" value="uncheck_by_default" <?php if ($instance['remember_me_def']=='uncheck_by_default') echo "checked='checked'"; ?>>Uncheck by default </label> <br>
			<label><input type="radio" name="<?php echo $this->get_field_name("remember_me_def"); ?>" value="check_by_default" <?php if ($instance['remember_me_def']=='check_by_default') echo "checked='checked'";?>>Check by default </label> 
			</p>
			</div> 
			</div>
			<p>
			<a href="#" class="sp_switch_logged_in"><strong>Logged In Options</strong></a>
			</p>
			<div style="display: none;" >
			<strong>Add Logged-In message</strong><br>
			<select ><?php self::print_merge_tags_options(); ?> </select>
			<textarea rows="" cols="" id="<?php echo $this->get_field_id("logged_in_text"); ?>" name="<?php echo $this->get_field_name("logged_in_text"); ?>" style="width: 100%;height: 100px;"><?php echo $logged_in_text; ?></textarea>
			</div>

			</div>
			
			<?php 
			wp_nonce_field(plugin_basename( __FILE__ ), 'pwLogWi_noncename');
			
		}
		
		static function print_merge_tags_options(){
			
			echo "<option value=''>Insert Merge Tag</option>";
			echo "<option value='display_name'>User display name</option>";
			echo "<option value='user_nicename'>User nice name</option>";
			echo "<option value='user_login'>User login</option>";
			echo "<option value='user_email'>User email</option>";
			echo "<option value='logout_link'>Log-out link</option>";
			echo "<option value='profile_link'>Profile link</option>";
			
		}
		
		/**
		 * Sanitize widget form values as they are saved.
		 *
		 * @see WP_Widget::update()
		 *
		 * @param array $new_instance Values just sent to be saved.
		 * @param array $old_instance Previously saved values from database.
		 *
		 * @return array Updated safe values to be saved.
		 */
		public function update( $new_instance, $old_instance ) {
			
			global $wp_registered_widgets;
			
			foreach ($wp_registered_widgets as $widget=>$values){
				if (preg_match("/pw_login_widget(.*)/", $widget)){
					$flag = true;	
				}
				
			}
		
			if (wp_verify_nonce($_POST['pwLogWi_noncename'], plugin_basename( __FILE__ ))){
				$instance = array();
				$instance['css_class'] = strip_tags( $new_instance['css_class'] );
				$instance['include_remember_me'] = strip_tags( $new_instance['include_remember_me'] );
				$instance['default_form'] = strip_tags($new_instance['default_form']);
				$instance['float'] = strip_tags($new_instance['float']);
				$instance['logged_in_text'] = $new_instance['logged_in_text'];
				$instance['remember_me_def'] = $new_instance['remember_me_def'];
			
				return $instance;
			}
			
			return $old_instance;
		
		}
		
		static function interapt_merge_tags($input_text, $redirect_url){
			
			$return_text = $input_text;
			$user = wp_get_current_user();
			$user_data = get_object_vars($user->data);
			preg_match_all("/\{([^\}]+)\}/", $input_text, $matches);
			foreach ($matches[1] as $match){
				switch ($match){

					case "display_name":
						$replace = empty($user_data["display_name"]) ? $user_data["user_login"] : $user_data["display_name"];
						$return_text = str_replace("{".$match."}", $replace, $return_text);
						break;
					case "user_nicename":
						$replace = empty($user_data["user_nicename"]) ? $user_data["user_login"] : $user_data["user_nicename"];
						$return_text = str_replace("{".$match."}", $replace, $return_text);
						break;
					case "user_login":
						$return_text = str_replace("{".$match."}", $user_data["user_login"], $return_text);
						break;
					case "user_email":
						$return_text = str_replace("{".$match."}", $user_data["user_email"], $return_text);
						break;
					case "logout_link":
						$return_text = str_replace("{".$match."}", "<a href='".wp_logout_url($redirect_url)."'>Log-Out</a>", $return_text);
						break;
					case "profile_link":
						$return_text = str_replace("{".$match."}", "<a href='".admin_url("profile.php")."'>Profile</a>", $return_text);
						break;
					
					
				}
				
			}
			return $return_text;
		}
		
		/**
		 * Front-end display of widget.
		 *
		 * @see WP_Widget::widget()
		 *
		 * @param array $args     Widget arguments.
		 * @param array $instance Saved values from database.
		 *
		 */
		public function widget( $args, $instance ) {
		
			extract( $args );

			$before_widget = preg_replace('/class="/', 'class="'.$instance['css_class'].' ', $before_widget, 1);
			echo $before_widget;
			
			if (isset($instance['css_class'])){
				$css_class = $instance[ 'css_class' ];
			}
			$include_remember_me = !empty($instance['include_remember_me']);
			if (isset($instance['default_form']) && $instance['default_form']=='register_form' ){
				$hide_login_div = "style='display: none'";
			}else{
				$hide_register_div = "style='display: none'";
			}
			if (isset($instance['float']) && $instance['float']=='horizontal'){
				$horizontal = "style='display:inline-block'"; 	
			}else{
				$horizontal = "";
			}
			
			if (is_user_logged_in()){
				$user = wp_get_current_user();
				if ( isset( $instance['logged_in_text'] ) && !empty( $instance['logged_in_text'] ) ) {
					$logged_in_text = self::interapt_merge_tags($instance['logged_in_text'], $_SERVER['REQUEST_URI']);
				}else{
					$logged_in_text = self::interapt_merge_tags("Welcome Back {user_login}. {logout_link}" , $_SERVER['REQUEST_URI']);
				}
				
				echo $logged_in_text;
				
				}else{
					$is_user_can_register = $this->check_user_can_register();
					?>
					<div id='sp-widget-login-div' <?php echo $hide_login_div; ?>>
					<form method="post" action="<?php bloginfo('url') ?>/wp-login.php" class="wp-user-form">
					<div id="username_label_div" <?php echo $horizontal; ?>><label for='user_login'>Username: </label></div>
					<div id="username_field_div" <?php echo $horizontal; ?>><input id='user_login' type='text' name='log' required='required' /></div>
					<div id="pass_label_div" <?php echo $horizontal; ?>><label for='user_pass'>Password: </label></div>
					<div id="pass_field_div" <?php echo $horizontal; ?>><input id='user_pass' type='password' name='pwd' required='required' /></div>
					<?php if ($include_remember_me){?>
					<div id="remember_me_div" <?php echo $horizontal; ?>><label for='rememberme1' ><input type='checkbox' name='rememberme' value='forever' <?php if ($instance['remember_me_def']=='check_by_default') echo "checked='checked'"; ?> id='rememberme1' /> Remember me</label></div>
					<?php }?>
					<div id="login_butt_div" <?php echo $horizontal; ?>><input type="submit" name="user-submit" value="Login" /></div>
					<?php do_action('login_form'); ?>
					<input type="hidden" name="redirect_to" value="<?php echo $_SERVER['REQUEST_URI']; ?>" />
					<input type="hidden" name="user-cookie" value="1" />
					</form>
					<?php if ($is_user_can_register){?><div id='goto_register_form_link' style="display: inline-block;"><a href='#sp-register'>Don't have an account?</a></div> | <?php }?>
					<div id='goto_forgot_password' style="display: inline-block;"><a href='#lost-pass'>Lost your password?</a></div>
					</div>
					
					<?php if ($is_user_can_register){?>
					<div id='sp-widget-register-div' <?php echo $hide_register_div; ?>>
					<form method="post" action="<?php echo site_url('wp-login.php?action=register', 'login_post') ?>" class="wp-user-form">
					<div id="choose_username_label_div" <?php echo $horizontal; ?>><label for='user_login'>Choose username: </label></div>
					<div id="chhose_username_field_div" <?php echo $horizontal; ?>><input id='user_login' type='text' name='user_login' required='required' /></div>
					<div id="email_label_div" <?php echo $horizontal; ?>><label for="user_email" >Your Email: </label></div>
					<div id="email_field_div" <?php echo $horizontal; ?>><input id="user_email" type="email" name="user_email" required="required" /></div>
					<div id="register_butt_div" <?php echo $horizontal; ?>><input type="submit" name="user-submit" value="Sign up!" /></div>
					<?php do_action('register_form'); ?>
					<input type="hidden" name="redirect_to" value="<?php echo $_SERVER['REQUEST_URI']; ?>?register=true" />
					<input type="hidden" name="user-cookie" value="1" />
					</form>
					<div class='goto_login_form_link'><a href='#sp-login'>Have an account?</a></div>
					</div>
					<?php }?>
					
					<div id='sp-widget-lost_pass-div' style='display:none;'>
					<form method="post" action='<?php echo site_url('wp-login.php?action=lostpassword', 'login_post'); ?>'>
					<div id="username/email_label_div" <?php echo $horizontal; ?>><label for='user_login'>Enter your username or email: </label></div>
					<div id="username/email_field_div" <?php echo $horizontal; ?>><input type="text" name="user_login" value="" size="20" id="user_login" /></div>
					<?php do_action('login_form', 'resetpass')?>
					<input type="submit" name="user-submit" value="<?php echo 'Reset my password'; ?>"  />
					<input type="hidden" name="redirect_to" value="<?php echo empty($_GET)? $_SERVER['REQUEST_URI']."?reset=true" : $_SERVER['REQUEST_URI']."&reset=true"; ?>" />
					<input type="hidden" name="user-cookie" value="1" />
					</form>
					<div class='goto_login_form_link'><a href='#sp-login'>Back to login</a></div>
					</div>
					<?php $reset = $_GET['reset']; if($reset == true) { echo '<p>A message was sent to your email address.</p>'; } ?>
					<div><?php $register = $_GET['register']; if($register == true) { echo '<p>Check your email for the password!</p>'; } ?></div>
					<?php 
				}// end if user logged out state
				
				echo $after_widget;
			}
			
			function check_user_can_register(){
				$register_url = wp_register('', '', false);
				return !empty($register_url);
			}
	
}

add_action('widgets_init', create_function('', 'register_widget( "Pw_Login_Widget" );'));

add_action('init', 'pw_register_styles_and_scripts');
function pw_register_styles_and_scripts(){
	wp_register_style('pwLogWi_admin_style', plugins_url('pw-login-widget.css' , __FILE__));
	wp_register_script( 'pwLogWi_script', plugins_url('pw-login-widget.js', __FILE__), array("jquery"));
}

add_action('admin_enqueue_scripts', 'pwLogWi_admin_enqueue_scripts' , 10 , 1);
function pwLogWi_admin_enqueue_scripts($hook){
	if ($hook=='widgets.php'){
		wp_enqueue_style('pwLogWi_admin_style' );
		wp_enqueue_script( 'pwLogWi_script' );
	}
}

add_action( 'wp_enqueue_scripts', 'pwLogWi_enqueue_scripts' );
function pwLogWi_enqueue_scripts(){
	wp_enqueue_style('pwLogWi_admin_style' );
	wp_enqueue_script( 'pwLogWi_script' );
	
}
 


?>